summaryrefslogtreecommitdiff
path: root/rjit_c.c
diff options
context:
space:
mode:
authorTakashi Kokubun <takashikkbn@gmail.com>2023-03-06 23:15:30 -0800
committerTakashi Kokubun <takashikkbn@gmail.com>2023-03-06 23:44:01 -0800
commit2e875549a934fa04b7939810fa0d8a2762702aaa (patch)
tree116b99056f810d48359ac6fa6a3b06e9ddc65c05 /rjit_c.c
parenteaccdc1941304d6273397b21c25213174d892185 (diff)
downloadruby-2e875549a934fa04b7939810fa0d8a2762702aaa.tar.gz
s/MJIT/RJIT/
Diffstat (limited to 'rjit_c.c')
-rw-r--r--rjit_c.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/rjit_c.c b/rjit_c.c
index 9af89c649d..4c22c89e4a 100644
--- a/rjit_c.c
+++ b/rjit_c.c
@@ -1,17 +1,17 @@
/**********************************************************************
- mjit_c.c - C helpers for MJIT
+ mjit_c.c - C helpers for RJIT
Copyright (C) 2017 Takashi Kokubun <k0kubun@ruby-lang.org>.
**********************************************************************/
-#include "ruby/internal/config.h" // defines USE_MJIT
+#include "ruby/internal/config.h" // defines USE_RJIT
// ISO C requires a translation unit to contain at least one declaration
void rb_mjit_c(void) {}
-#if USE_MJIT
+#if USE_RJIT
#include "mjit.h"
#include "mjit_c.h"
@@ -42,7 +42,7 @@ void rb_mjit_c(void) {}
#define SIZEOF(type) RB_SIZE2NUM(sizeof(type))
#define SIGNED_TYPE_P(type) RBOOL((type)(-1) < (type)(1))
-#if MJIT_STATS
+#if RJIT_STATS
// Insn side exit counters
static size_t mjit_insn_exits[VM_INSTRUCTION_SIZE] = { 0 };
#endif // YJIT_STATS
@@ -83,7 +83,7 @@ dump_disasm(rb_execution_context_t *ec, VALUE self, VALUE from, VALUE to)
return result;
}
// Same as `RubyVM::MJIT.enabled?`, but this is used before it's defined.
static VALUE
mjit_enabled_p(rb_execution_context_t *ec, VALUE self)
{
@@ -122,4 +122,4 @@ extern ID rb_get_symbol_id(VALUE name);
#include "mjit_c.rbinc"
-#endif // USE_MJIT
+#endif // USE_RJIT
@@ -83,7 +83,7 @@ dump_disasm(rb_execution_context_t *ec, VALUE self, VALUE from, VALUE to)
return result;
}
-// Same as `RubyVM::MJIT.enabled?`, but this is used before it's defined.
+// Same as `RubyVM::RJIT.enabled?`, but this is used before it's defined.
static VALUE
mjit_enabled_p(rb_execution_context_t *ec, VALUE self)